@@ -47,10 +47,8 @@ import (
 )
 
 const (
-	rootGCPCredsSecretNamespace = "kube-system"
-	rootGCPCredsSecret          = "gcp-credentials"
-	roGCPCredsSecretNamespace   = "openshift-cloud-credential-operator"
-	roGCPCredsSecret            = "cloud-credential-operator-iam-ro-creds"
+	roGCPCredsSecretNamespace = "openshift-cloud-credential-operator"
+	roGCPCredsSecret          = "cloud-credential-operator-iam-ro-creds"
 
 	gcpSecretJSONKey = "service_account.json"
 )
@@ -341,7 +339,7 @@ func (a *Actuator) syncMint(ctx context.Context, cr *minterv1.CredentialsRequest
 		if status.Code(err) == codes.NotFound {
 			logger.WithField("serviceaccount", gcpStatus.ServiceAccountID).Debug("service account does not exist, creating")
 			if rootGCPClient == nil {
-				return fmt.Errorf("no root GCP client available, cred secret may not exist: %s/%s", rootGCPCredsSecretNamespace, rootGCPCredsSecret)
+				return fmt.Errorf("no root GCP client available, cred secret may not exist: %s/%s", constants.CloudCredSecretNamespace, constants.GCPCloudCredSecretName)
 			}
 		} else {
 			return fmt.Errorf("error checking for existing service account: %v", err)
@@ -496,10 +494,10 @@ func (a *Actuator) needsUpdate(ctx context.Context, cr *minterv1.CredentialsRequ
 }
 
 func (a *Actuator) buildRootGCPClient(cr *minterv1.CredentialsRequest) (ccgcp.Client, error) {
-	logger := a.getLogger(cr).WithField("secret", fmt.Sprintf("%s/%s", rootGCPCredsSecretNamespace, rootGCPCredsSecret))
+	logger := a.getLogger(cr).WithField("secret", fmt.Sprintf("%s/%s", constants.CloudCredSecretNamespace, constants.GCPCloudCredSecretName))
 
 	logger.Debug("loading GCP credentials from secret")
-	jsonBytes, err := loadCredsFromSecret(a.Client, rootGCPCredsSecretNamespace, rootGCPCredsSecret)
+	jsonBytes, err := loadCredsFromSecret(a.Client, constants.CloudCredSecretNamespace, constants.GCPCloudCredSecretName)
 	if err != nil {
 		return nil, err
 	}
@@ -517,7 +515,7 @@ func (a *Actuator) buildReadGCPClient(cr *minterv1.CredentialsRequest) (ccgcp.Cl
 
 	if cr.Spec.SecretRef.Name == roGCPCredsSecret && cr.Spec.SecretRef.Namespace == roGCPCredsSecretNamespace {
 		log.Debug("operating our own RO creds, using root creds for GCP client operator")
-		jsonBytes, err = loadCredsFromSecret(a.Client, rootGCPCredsSecretNamespace, rootGCPCredsSecret)
+		jsonBytes, err = loadCredsFromSecret(a.Client, constants.CloudCredSecretNamespace, constants.GCPCloudCredSecretName)
 		if err != nil {
 			return nil, err
 		}
@@ -563,10 +561,15 @@ func (a *Actuator) updateProviderStatus(ctx context.Context, logger log.FieldLog
 	return nil
 }
 
+// GetCredentialsRootSecretLocation returns the namespace and name where the parent credentials secret is stored.
+func (a *Actuator) GetCredentialsRootSecretLocation() types.NamespacedName {
+	return types.NamespacedName{Namespace: constants.CloudCredSecretNamespace, Name: constants.GCPCloudCredSecretName}
+}
+
 // getRootCloudCredentialsSecret will return the cluster's root GCP cloud cred secret if it exists and is properly annotated
 func (a *Actuator) getRootCloudCredentialsSecret(ctx context.Context, logger log.FieldLogger) (*corev1.Secret, error) {
 	cloudCredSecret := &corev1.Secret{}
-	if err := a.Client.Get(ctx, types.NamespacedName{Name: rootGCPCredsSecret, Namespace: rootGCPCredsSecretNamespace}, cloudCredSecret); err != nil {
+	if err := a.Client.Get(ctx, a.GetCredentialsRootSecretLocation(), cloudCredSecret); err != nil {
 		msg := "unable to fetch root cloud cred secret"
 		logger.WithError(err).Error(msg)
 		return nil, &actuatoriface.ActuatorError{
@@ -576,7 +579,7 @@ func (a *Actuator) getRootCloudCredentialsSecret(ctx context.Context, logger log
 	}
 
 	if !isSecretAnnotated(cloudCredSecret) {
-		logger.WithField("secret", fmt.Sprintf("%s/%s", rootGCPCredsSecretNamespace, rootGCPCredsSecret)).Error("cloud cred secret not yet annotated")
+		logger.WithField("secret", fmt.Sprintf("%s/%s", constants.CloudCredSecretNamespace, constants.GCPCloudCredSecretName)).Error("cloud cred secret not yet annotated")
 		return nil, &actuatoriface.ActuatorError{
 			ErrReason: minterv1.CredentialsProvisionFailure,
 			Message:   fmt.Sprintf("cannot proceed without cloud cred secret annotation"),
