@@ -61,7 +61,7 @@ func LoadCredsFromSecret(kubeClient client.Client, namespace, secretName string)
 // LoadInfrastructureName loads the cluster Infrastructure config and returns the infra name
 // used to identify this cluster, and tag some cloud objects.
 func LoadInfrastructureName(c client.Client, logger log.FieldLogger) (string, error) {
-	infra, err := getInfrastructure(c)
+	infra, err := GetInfrastructure(c)
 	if err != nil {
 		logger.WithError(err).Error("error loading Infrastructure config 'cluster'")
 		return "", err
@@ -72,7 +72,7 @@ func LoadInfrastructureName(c client.Client, logger log.FieldLogger) (string, er
 
 // LoadInfrastructureRegion loads the AWS region the cluster is installed to.
 func LoadInfrastructureRegion(c client.Client, logger log.FieldLogger) (string, error) {
-	infra, err := getInfrastructure(c)
+	infra, err := GetInfrastructure(c)
 	if err != nil {
 		logger.WithError(err).Error("error loading Infrastructure region")
 		return "", err
@@ -81,12 +81,16 @@ func LoadInfrastructureRegion(c client.Client, logger log.FieldLogger) (string,
 		// Older clusters may have an Infrastructure object without the PlatformStatus fields.
 		// Send back an empty region and the AWS client will use default settings.
 		// The permissions simulation will also simply not fill out the region for simulations.
+		// TODO: Once the oldest supported version of OpenShift includes the new migration operator,
+		// we can remove this legacy handling and know that PlatformStatus/Region is set
+		// https://github.com/openshift/cloud-credential-operator/pull/195#discussion_r432089284
 		return "", nil
 	}
 	return infra.Status.PlatformStatus.AWS.Region, nil
 }
 
-func getInfrastructure(c client.Client) (*configv1.Infrastructure, error) {
+// GetInfrastructure will return the cluster's Infrastructure object.
+func GetInfrastructure(c client.Client) (*configv1.Infrastructure, error) {
 	infra := &configv1.Infrastructure{}
 	if err := c.Get(context.TODO(), types.NamespacedName{Name: "cluster"}, infra); err != nil {
 		return nil, err
@@ -153,7 +157,6 @@ func isOperatorDisabledViaConfigmap(kubeClient client.Client, logger log.FieldLo
 	cm, err := GetLegacyConfigMap(kubeClient)
 	if err != nil {
 		if errors.IsNotFound(err) {
-			logger.Debugf("%s ConfigMap does not exist, assuming default behavior", constants.CloudCredOperatorConfigMap)
 			return OperatorDisabledDefault, nil
 		}
 		return OperatorDisabledDefault, err
@@ -167,7 +170,7 @@ func GetLegacyConfigMap(kubeClient client.Client) (*corev1.ConfigMap, error) {
 	err := kubeClient.Get(context.TODO(),
 		types.NamespacedName{
 			Namespace: minterv1.CloudCredOperatorNamespace,
-			Name:      minterv1.CloudCredOperatorConfigMap,
+			Name:      constants.CloudCredOperatorConfigMap,
 		}, cm)
 	return cm, err
 }
@@ -254,7 +257,7 @@ func getOperatorMode(kubeClient client.Client, logger log.FieldLogger) (operator
 func CCODisabledCheck(cm *corev1.ConfigMap, logger log.FieldLogger) (bool, error) {
 	disabled, ok := cm.Data[operatorConfigMapDisabledKey]
 	if !ok {
-		logger.Debugf("%s ConfigMap has no %s key, assuming default behavior", minterv1.CloudCredOperatorConfigMap, operatorConfigMapDisabledKey)
+		logger.Debugf("%s ConfigMap has no %s key, assuming default behavior", constants.CloudCredOperatorConfigMap, operatorConfigMapDisabledKey)
 		return OperatorDisabledDefault, nil
 	}
 	return strconv.ParseBool(disabled)
